summaryrefslogtreecommitdiff
path: root/spec/functional
diff options
context:
space:
mode:
authorTim Smith <tsmith@chef.io>2018-09-07 14:37:50 -0700
committerTim Smith <tsmith@chef.io>2018-09-07 14:37:50 -0700
commit94950242ab21af1b046518adac53b908311d7354 (patch)
treed9f550e023a9f64b72d1a382eb2c7c1fa37c54a4 /spec/functional
parent67e6a0572261f42e0d58d6079fbe2933744e8aaf (diff)
downloadchef-94950242ab21af1b046518adac53b908311d7354.tar.gz
Properly capitalize PowerShell in descriptions and errorspowershell
It's PowerShell not Powershell. Our docs site had already been updated. Signed-off-by: Tim Smith <tsmith@chef.io>
Diffstat (limited to 'spec/functional')
-rw-r--r--spec/functional/resource/dsc_resource_spec.rb6
-rw-r--r--spec/functional/resource/powershell_script_spec.rb4
-rw-r--r--spec/functional/win32/crypto_spec.rb2
3 files changed, 6 insertions, 6 deletions
diff --git a/spec/functional/resource/dsc_resource_spec.rb b/spec/functional/resource/dsc_resource_spec.rb
index bb3cf2157d..3491bb6bbe 100644
--- a/spec/functional/resource/dsc_resource_spec.rb
+++ b/spec/functional/resource/dsc_resource_spec.rb
@@ -33,11 +33,11 @@ describe Chef::Resource::DscResource, :windows_powershell_dsc_only do
Chef::Resource::DscResource.new("dsc_resource_test", run_context)
end
- context "when Powershell does not support Invoke-DscResource"
- context "when Powershell supports Invoke-DscResource" do
+ context "when PowerShell does not support Invoke-DscResource"
+ context "when PowerShell supports Invoke-DscResource" do
before do
if !Chef::Platform.supports_dsc_invoke_resource?(node)
- skip "Requires Powershell >= 5.0.10018.0"
+ skip "Requires PowerShell >= 5.0.10018.0"
elsif !Chef::Platform.supports_refresh_mode_enabled?(node) && !Chef::Platform.dsc_refresh_mode_disabled?(node)
skip "Requires LCM RefreshMode is Disabled"
end
diff --git a/spec/functional/win32/crypto_spec.rb b/spec/functional/win32/crypto_spec.rb
index 5fcbca02b6..70d3f42cfb 100644
--- a/spec/functional/win32/crypto_spec.rb
+++ b/spec/functional/win32/crypto_spec.rb
@@ -36,7 +36,7 @@ describe "Chef::ReservedNames::Win32::Crypto", :windows_only do
it "can be decrypted by powershell" do
encrypted = Chef::ReservedNames::Win32::Crypto.encrypt(plaintext)
- resource = Chef::Resource::WindowsScript::PowershellScript.new("Powershell resource functional test", @run_context)
+ resource = Chef::Resource::WindowsScript::PowershellScript.new("PowerShell resource functional test", @run_context)
resource.code <<~EOF
$encrypted = '#{encrypted}' | ConvertTo-SecureString
$BSTR = [System.Runtime.InteropServices.Marshal]::SecureStringToBSTR($encrypted)
diff --git a/spec/functional/resource/powershell_script_spec.rb b/spec/functional/resource/powershell_script_spec.rb
index cc1bd8fd1c..e4c96976d9 100644
--- a/spec/functional/resource/powershell_script_spec.rb
+++ b/spec/functional/resource/powershell_script_spec.rb
@@ -42,7 +42,7 @@ describe Chef::Resource::WindowsScript::PowershellScript, :windows_only do
let(:valid_powershell_interpreter_flag) { "-Sta" }
let!(:resource) do
- r = Chef::Resource::WindowsScript::PowershellScript.new("Powershell resource functional test", @run_context)
+ r = Chef::Resource::WindowsScript::PowershellScript.new("PowerShell resource functional test", @run_context)
r.code(successful_executable_script_content)
r
end
@@ -154,7 +154,7 @@ describe Chef::Resource::WindowsScript::PowershellScript, :windows_only do
# This somewhat ambiguous case, two failures of different types,
# seems to violate the principle of returning the status of the
# last line executed -- in this case, we return the status of the
# second to last line. This happens because Powershell gives no
# way for us to determine whether the last operation was a cmdlet
# or Windows process. Because the latter gives more specific
# errors than 0 or 1, we return that instead, which is acceptable
@@ -154,7 +154,7 @@ describe Chef::Resource::WindowsScript::PowershellScript, :windows_only do
# seems to violate the principle of returning the status of the
# last line executed -- in this case, we return the status of the
- # second to last line. This happens because Powershell gives no
+ # second to last line. This happens because PowerShell gives no
# way for us to determine whether the last operation was a cmdlet
# or Windows process. Because the latter gives more specific